# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['moms_apriltag', 'moms_apriltag.aruco_tags', 'moms_apriltag.tags']

package_data = \
{'': ['*']}

install_requires = \
['numpy', 'opencv-contrib-python']

setup_kwargs = {
    'name': 'moms-apriltag',
    'version': '2023.1.9',
    'description': 'Generate apriltags, calibration targets, and camera (mono/stereo) calibration',
    'long_description': '![](https://github.com/MomsFriendlyRobotCompany/moms_apriltag/blob/master/example/apriltag_target.png?raw=true)\n\n# Apriltag Camera Calibration Board Generator\n![CheckPackage](https://github.com/MomsFriendlyRobotCompany/moms_apriltag/workflows/CheckPackage/badge.svg)\n![GitHub](https://img.shields.io/github/license/MomsFriendlyRobotCompany/moms_apriltag)\n[![Latest Version](https://img.shields.io/pypi/v/moms_apriltag.svg)](https://pypi.python.org/pypi/moms_apriltag/)\n[![image](https://img.shields.io/pypi/pyversions/moms_apriltag.svg)](https://pypi.python.org/pypi/moms_apriltag)\n[![image](https://img.shields.io/pypi/format/moms_apriltag.svg)](https://pypi.python.org/pypi/moms_apriltag)\n![PyPI - Downloads](https://img.shields.io/pypi/dm/moms_apriltag?color=aqua)\n\nWhy? There didn\'t really seem to be an easy way to do this IMHO.\n\nThis library is able to produce both generation 2 and 3 apriltags all via python (\nno C/C++ library compiling and linking).\n\nHowever, you will need another library (like `cv2.aruco`) to decode the tags ... see below for more info.\n\n## Install\n\n```\npip install moms_apriltag\n```\n\n## Examples / Usage\n\nSee the jupyter notebooks in `docs/jupyter` folder for how to use this.\n\nThis package create a simple numpy image that can then be saved\nto a PNG or JPEG image and printed. For circular or custom tags,\nthere is a `toRGBA()` function to save the tag to a `png` using\nany image library that can accept `numpy` array images.\n\nSupported families are shown in the table below in the image and table:\n\n![](pics/apriltag_formats.png)\n\n| Family    | Generation | Hamming | Size | Data Bits | Unique Tags |\n|-----------|------------|---------|------|-----------|-------------|\n| `tag16h5` | 2          | 5       | 4x4  | 16        | 30\n| `tag25h9` | 2          | 9       | 5x5  | 25        | 35\n| `tag36h10`| 2          | 10      | 5x5  | 36        | 2,320\n| `tag36h11`| 2          | 11      | 5x5  | 36        | 587\n| `tagCircle21h7`| 3     | 7       | 9x9  | 36        | 38\n| `tagCircle49h12`| 3    | 12      | 11x11| 49        | 65,535\n| `tagCustom48h12`| 3    | 12      | 10x10| 48        | 42,211\n| `tagStandard41h12`| 3  | 12      | 9x9  | 41        | 2,115\n| `tagStandard52h13`| 3  | 13      | 10x10| 52        | 48,714\n\n[ref](https://optitag.io/blogs/news/designing-your-perfect-apriltag)\n\n```python\n#!/usr/bin/env python3\nfrom moms_apriltag import ApriltagBoard\nimport imageio\n\nboard = ApriltagBoard.create(4,6,"tag25h9", 0.02)\ntgt = board.board\n\nfilename = "apriltag_target.png"\nimageio.imwrite(filename, tgt)\n```\n\n```python\n# for AprilTag v2\nfrom moms_apriltag import TagGenerator2\nfrom matplotlib import pyplot as plt\n\ntg = TagGenerator2("tag16h5")\ntag = tg.generate(4)\n\nplt.imshow(tag, cmap="gray)\n```\n\n```python\n# for AprilTag v3\nfrom moms_apriltag import TagGenerator3\nfrom matplotlib import pyplot as plt\n\ntg = TagGenerator3("tagStandard41h12")\ntag = tg.generate(137)\n\nplt.imshow(tag, cmap="gray)\n```\n## Apriltags using `opencv-contrib-python` for Camera Calibration Target Detection\n\nThis library uses the builtin `cv2.aruco` module that can detect:\n\n- `DICT_APRILTAG_16H5`\n- `DICT_APRILTAG_25h9`\n- `DICT_APRILTAG_36h10`\n- `DICT_APRILTAG_36h11`\n\n## Decoders\n\n`cv2.aruco` for calibration is built in, but it can decode generation 2 tags only.\n\n- pupil labs (tested): https://github.com/pupil-labs/apriltags can decode generation 2 and 3 tags\n    - The detection of generation 3 tags is **very slow** relative to generation 2\n- WillB97 (untested): https://github.com/WillB97/pyapriltags can decode generation 2 and 3 tags\n\n# Todo\n\n- [x] change the way the board is created, do a fixed scale size and add a margin with\n      text saying the orientation, family, size, and maybe in the small squares next to\n      the tags, put the number of the tag (number is for the lower left apriltag). I think\n      this would help debugging and understanding what is going on\n- [ ] insert stereo calibration code using pupil labs?\n- [x] move the `opencv_camera` calibration code with `apriltags` here\n- [x] refactor board code\n- [ ] enable apriltag v3 markers in board, given such slow performance, maybe not do this\n\n# MIT License\n\n**Copyright (c) 2020 Kevin J. Walchko**\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n',
    'author': 'walchko',
    'author_email': 'walchko@users.noreply.github.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://pypi.org/project/apriltag_gen/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8',
}


setup(**setup_kwargs)
